︠7b7bd273-3116-48d1-8f58-f3569fac7113s︠
#A latin square is an nxn matrix with n symbols in each row and each column
#One can turn a latin square into an orthogonal array by making a 3 tuple(i,j,z)
#such that i is the row, j is the column, and z is the ijth entry
#Make

from sage.combinat.matrices.latin import *

K4 = LatinSquare(matrix(ZZ, [[0,1,2,3],
                             [1,0,3,2],
                             [2,3,0,1],
                             [3,2,1,0]]))
K4
︡beb45877-edb7-41dc-855f-11a1a0697a5a︡{"stdout":"[0 1 2 3]\n[1 0 3 2]\n[2 3 0 1]\n[3 2 1 0]\n"}︡{"done":true}
︠e77fac0f-3b9b-471a-9bb5-0d1bf512d6b9s︠
C4 = LatinSquare(matrix(ZZ, [[0,1,2,3],
                             [1,2,3,0],
                             [2,3,0,1],
                             [3,0,1,2]]))

C4
︡e5ef3df8-9450-4871-adf9-89df42866799︡{"stdout":"[0 1 2 3]\n[1 2 3 0]\n[2 3 0 1]\n[3 0 1 2]\n"}︡{"done":true}
︠b2c7ed8c-52b7-4293-9739-1c3e2f8b4557s︠
#vertices are indices

def MakeOrthogonalArray(M):
    if not M.is_latin_square(): # check M is a latin square
        return False
    n = M.nrows()#order of M
    array = [(i,j) for i in range(n) for j in range(n)]
    OA = []
    for x in array:
        OA.append(x+(M[x],))
    return OA

︡01cbf941-358a-4b5c-9b75-64235fb2c6ff︡{"done":true}
︠46065b5a-1daf-4d46-9235-3db425fab256s︠
MakeOrthogonalArray(C4)
︡f74238fc-f7e8-40fd-a77e-2ae336a059d0︡{"stdout":"[(0, 0, 0), (0, 1, 1), (0, 2, 2), (0, 3, 3), (1, 0, 1), (1, 1, 2), (1, 2, 3), (1, 3, 0), (2, 0, 2), (2, 1, 3), (2, 2, 0), (2, 3, 1), (3, 0, 3), (3, 1, 0), (3, 2, 1), (3, 3, 2)]\n"}︡{"done":true}
︠92060821-787a-477a-8d5e-11aae3462d84s︠

def LatinSquareGraph(M):
    OA = MakeOrthogonalArray(M)
    G = Graph()
    G.add_vertices(OA)
    edges = []
    for u in OA:
        for v in OA:
            if u!= v:
                if (v,u) not in edges:
                    if u[0] == v[0]:
                        edges.append((u,v))
                    elif u[1] == v[1]:
                        edges.append((u,v))
                    elif u[2] == v[2]:
                        edges.append((u,v))
    G.add_edges(edges)

    return G

︡35aacf63-2e4f-46db-b5ae-dfb2f7bbd391︡{"done":true}
︠3254a001-e6e1-4884-8189-6dc8a25c0a52s︠
LatinSquareGraph(C4).show(figsize=3)
︡c0863a23-c1ac-4b8a-8ed8-09f833cb49bb︡{"file":{"filename":"/home/user/.sage/temp/project-ddacd291-f3cc-4c29-a5d7-e6f86663e5ce/376/tmp_0DVu51.svg","show":true,"text":null,"uuid":"53aeb501-9d47-424b-b9cb-766da0222da4"},"once":false}︡{"done":true}
︠b88a0e94-cd94-4aff-a755-a581407e9615s︠
LatinSquareGraph(K4).show(figsize=3)
︡726c9c4a-ca0f-421d-a0eb-013905e74d74︡{"file":{"filename":"/home/user/.sage/temp/project-ddacd291-f3cc-4c29-a5d7-e6f86663e5ce/376/tmp_RUojWs.svg","show":true,"text":null,"uuid":"4092ae3c-7aa4-498a-ba60-fcd2d2123157"},"once":false}︡{"done":true}
︠35c90f3f-feb4-4658-a9ed-7af7aad6d138s︠
def checkLSGareIsomorphic(A,B):
    return LatinSquareGraph(A).is_isomorphic(LatinSquareGraph(B))
︡109a812e-9f5d-4dc3-bc48-3ab41d7f263a︡{"done":true}
︠47275475-e54f-4eb7-840c-a0c77c304d91s︠
checkLSGareIsomorphic(K4,C4)
︡3716e5ed-b1f9-40d0-a3c4-4bdd09fb3dbc︡{"stdout":"False\n"}︡{"done":true}
︠b0cbb7cf-e3d4-4317-a350-5f4046b7a21as︠
from sage.combinat.designs.latin_squares import mutually_orthogonal_latin_squares

MOLS3 = mutually_orthogonal_latin_squares(2, 3)
︡f1ff709d-0f41-4da6-b14a-ffb21a9b60b6︡{"done":true}
︠1a3d2490-16d8-45c9-8d82-f340467bd142s︠
checkLSGareIsomorphic(LatinSquare(MOLS3[0]),LatinSquare(MOLS3[1]))
︡9a8801ee-37e8-4810-a10b-af2cba7ddbd7︡{"stdout":"True\n"}︡{"done":true}
︠370f4bde-d48c-436e-8061-ac2691d20479s︠
from itertools import combinations


def CheckSetOfMOLSIsomorphic(n):
    MOLS = mutually_orthogonal_latin_squares(n-1, n)
    k = len(MOLS)
    domain = combinations(range(k),2)
    TruthTable = []
    for x in domain:
        boolean = checkLSGareIsomorphic(LatinSquare(MOLS[x[0]]),LatinSquare(MOLS[x[1]]))
        if boolean == False:
            break
        else:
            TruthTable.append(boolean)
    return set(TruthTable)


︡9299c2b4-1a23-4dbd-a453-c4ec12e304b1︡{"done":true}
︠c16984da-2cf3-4d12-9529-e9ba2aabbba3s︠
l = [3,4,5,7,8,9,11,13]
for i in l:
    CheckSetOfMOLSIsomorphic(i)
︡06119068-4151-4d8e-acf7-5c2d13aeaf8b︡{"stdout":"set([True])\nset([True])"}︡{"stdout":"\nset([True])\nset([True])"}︡{"stdout":"\nset([True])"}︡{"stdout":"\nset([True])"}︡{"stdout":"\n"}︡{"stderr":"Error in lines 2-3\n"}︡{"stderr":"Traceback (most recent call last):\n  File \"/cocalc/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 1234, in execute\n    flags=compile_flags), namespace, locals)\n  File \"\", line 2, in <module>\n  File \"\", line 7, in CheckSetOfMOLSIsomorphic\n  File \"\", line 2, in checkLSGareIsomorphic\n  File \"\", line 9, in LatinSquareGraph\n  File \"src/cysignals/signals.pyx\", line 320, in cysignals.signals.python_check_interrupt\nKeyboardInterrupt\n"}︡{"done":true}
︠6d025c23-ba12-43bf-86b4-bf1a8a4da0eds︠
#i believe these were the latin squares reffered to
#https://www.sciencedirect.com/science/article/pii/0315086081900057

A = LatinSquare(matrix(ZZ,[[0,4,1,7,2,9,8,3,6,5],
                           [8,1,5,2,7,3,9,4,0,6],
                           [9,8,2,6,3,7,4,5,1,0],
                           [5,9,8,3,0,4,7,6,2,1],
                           [7,6,9,8,4,1,5,0,3,2],
                           [6,7,0,9,8,5,2,1,4,3],
                           [3,0,7,1,9,8,6,2,5,4],
                           [1,2,3,4,5,6,0,7,8,9],
                           [2,3,4,5,6,0,1,8,9,7],
                           [4,5,6,0,1,2,3,9,7,8]]))
B = LatinSquare(matrix(ZZ, [[0,7,8,6,9,3,5,4,1,2],
                           [6,1,7,8,0,9,4,5,2,3],
                           [5,0,2,7,8,1,9,6,3,4],
                           [9,6,1,3,7,8,2,0,4,5],
                           [3,9,0,2,4,7,8,1,5,6],
                           [8,4,9,1,3,5,7,2,6,0],
                           [7,8,5,9,2,4,6,3,0,1],
                           [4,5,6,0,1,2,3,7,8,9],
                           [1,2,3,4,5,6,0,9,7,8],
                           [2,3,4,5,6,0,1,8,9,7]]))
checkLSGareIsomorphic(A,B)
︡d0afd82d-a5b0-47e3-937d-f62823d17c1b︡{"stdout":"True"}︡{"stdout":"\n"}︡{"done":true}
︠2153dd5f-0c0f-40a1-a8f2-ce5d4871618bs︠

︡1dc31d24-bbc2-4b3a-b993-2f9daabfb16c︡{"done":true}
︠b5b73d7d-125c-4058-9c95-b579374d6c29s︠
C4inverse = LatinSquare(matrix(ZZ, [[0,3,2,1],
                                    [1,0,3,2],
                                    [2,1,0,3],
                                    [3,2,1,0]]))
︡e7e61dcf-d3da-4b85-a8cd-12e0c452f0b2︡{"done":true}
︠df7da8a2-9b91-497e-87df-b857bd225f36s︠
checkLSGareIsomorphic(C4,C4inverse)
︡2f317d02-bf08-4a6e-9623-0f840ff2ba91︡{"stdout":"True\n"}︡{"done":true}
︠b8c69b2f-2a7a-4f97-8055-8d0f37efb4a5s︠
A = LatinSquare(matrix(ZZ,[[0,4,1,7,2,9,8,3,6,5],
                           [8,1,5,2,7,3,9,4,0,6],
                           [9,8,2,6,3,7,4,5,1,0],
                           [5,9,8,3,0,4,7,6,2,1],
                           [7,6,9,8,4,1,5,0,3,2],
                           [6,7,0,9,8,5,2,1,4,3],
                           [3,0,7,1,9,8,6,2,5,4],
                           [1,2,3,4,5,6,0,7,8,9],
                           [2,3,4,5,6,0,1,8,9,7],
                           [4,5,6,0,1,2,3,9,7,8]]))
B = LatinSquare(matrix(ZZ, [[0,7,8,6,9,3,5,4,1,2],
                           [6,1,7,8,0,9,4,5,2,3],
                           [5,0,2,7,8,1,9,6,3,4],
                           [9,6,1,3,7,8,2,0,4,5],
                           [3,9,0,2,4,7,8,1,5,6],
                           [8,4,9,1,3,5,7,2,6,0],
                           [7,8,5,9,2,4,6,3,0,1],
                           [4,5,6,0,1,2,3,7,8,9],
                           [1,2,3,4,5,6,0,9,7,8],
                           [2,3,4,5,6,0,1,8,9,7]]))
checkLSGareIsomorphic(A,B)
︡3ecde141-9891-4b42-a5e1-97253d3108dd︡{"stdout":"True"}︡{"stdout":"\n"}︡{"done":true}
︠b4e915b1-ecc7-4b3b-8a43-ffa434c16ca9s︠
z3z3 = LatinSquare(matrix(ZZ, [[0,1,2,3,4,5,6,7,8],
                               [1,2,0,4,5,3,7,8,6],
                               [2,0,1,5,3,4,8,6,7],
                               [3,4,5,6,7,8,0,1,2],
                               [4,5,3,7,8,6,1,2,0],
                               [5,3,4,8,6,7,2,0,1],
                               [6,7,8,0,1,2,3,4,5],
                               [7,8,6,1,2,0,4,5,3],
                               [8,6,7,2,0,1,5,3,4]]))
patchedgalois = LatinSquare(matrix(ZZ,   [[0,1,2,3,4,5,6,7,8],
                                          [2,0,1,6,8,7,3,5,4],
                                          [3,6,0,4,7,1,8,2,5],
                                          [4,8,7,0,2,3,5,6,1],
                                          [5,7,1,3,0,8,2,4,6],
                                          [6,3,8,5,2,0,4,1,7],
                                          [7,5,2,6,4,1,0,8,3],
                                          [8,4,5,1,6,7,3,0,2],
                                          [8,4,5,1,6,7,3,0,2]]))
checkLSGareIsomorphic(z3z3,patchedgalois)
︡ebd95eb6-37e8-4600-9d00-065393d45a20︡{"stderr":"Error in lines 19-19\n"}︡{"stderr":"Traceback (most recent call last):\n  File \"/cocalc/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 1234, in execute\n    flags=compile_flags), namespace, locals)\n  File \"\", line 1, in <module>\n  File \"\", line 2, in checkLSGareIsomorphic\n  File \"\", line 4, in LatinSquareGraph\n  File \"/ext/sage/sage-8.9_1804/local/lib/python2.7/site-packages/sage/graphs/generic_graph.py\", line 9962, in add_vertices\n    return self._backend.add_vertices(vertices)\n  File \"sage/graphs/base/c_graph.pyx\", line 1491, in sage.graphs.base.c_graph.CGraphBackend.add_vertices (build/cythonized/sage/graphs/base/c_graph.cpp:14300)\n    for v in vertices:\nTypeError: 'bool' object is not iterable\n"}︡{"done":true}
︠3f0ea068-009e-4bb9-9add-27af8979b9d1s︠



LatinSquareGraph(z3z3)
︡847b7958-d9a2-4d79-8c92-003890d353a8︡{"stdout":"Graph on 81 vertices"}︡{"stdout":"\n"}︡{"done":true}
︠ee4ad8a2-91d4-4516-8c12-a8ca16f0a93cs︠
LatinSquareGraph(patchedgalois)
︡9f9cde25-ce5a-4257-99b7-8ccc219e3718︡{"stderr":"Error in lines 1-1\nTraceback (most recent call last):\n  File \"/cocalc/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 1234, in execute\n    flags=compile_flags), namespace, locals)\n  File \"\", line 1, in <module>\n  File \"\", line 4, in LatinSquareGraph\n  File \"/ext/sage/sage-8.9_1804/local/lib/python2.7/site-packages/sage/graphs/generic_graph.py\", line 9962, in add_vertices\n    return self._backend.add_vertices(vertices)\n  File \"sage/graphs/base/c_graph.pyx\", line 1491, in sage.graphs.base.c_graph.CGraphBackend.add_vertices (build/cythonized/sage/graphs/base/c_graph.cpp:14300)\n    for v in vertices:\nTypeError: 'bool' object is not iterable\n"}︡{"done":true}
︠d75e1e1a-4522-4a9a-b490-c67c9631a232s︠
# moore penrose inverse
#eigenvalues and eigenvectors
AC4 = LatinSquareGraph(C4).adjacency_matrix()
︡a32c5aa6-3da9-43b7-b2eb-7ce0b5d22735︡{"done":true}
︠d94dda49-2ea9-40eb-b20a-7fdb1f75c7bfs︠
import numpy as np
︡cc0f8627-80e7-4098-beab-2e1b91a49f81︡{"done":true}
︠ee197692-53b5-4579-a867-7062d2f5800bs︠
k,v = np.linalg.eig(AC4)
︡541d9a4f-2c1b-4a1d-9ff3-6d0022ec4188︡{"done":true}
︠44e046fb-c957-4004-a167-fb7d794ce089s︠
k
︡24d2a77b-ad3b-4742-aae5-f860e9d08667︡{"stdout":"array([ 9.,  1., -3., -3.,  1.,  1., -3., -3.,  1.,  1.,  1., -3., -3.,\n        1.,  1.,  1.])\n"}︡{"done":true}
︠25f45923-286a-45b4-b044-228f3945f41es︠
v[0]
︡4903381a-7f6f-49d9-b525-833d33b4b0e7︡{"stdout":"array([-2.50000000e-01, -7.50000000e-01,  6.12372436e-01,  4.40872589e-02,\n        1.91979711e-02,  6.71717729e-02,  9.37929507e-02, -2.64791788e-02,\n        3.61791639e-04, -9.57753160e-03, -5.86698663e-02, -1.38229348e-01,\n       -3.80950220e-02,  2.71419396e-02, -5.29406437e-02,  2.91543570e-02])\n"}︡{"done":true}
︠12b1db5f-9751-4181-9452-59249b56575bs︠
v[1]
︡10c5eda3-9927-4a68-a252-268a790b0a75︡{"stdout":"array([-0.25      , -0.08333333, -0.20412415, -0.45918803, -0.4961923 ,\n       -0.31859765,  0.32875918,  0.07846665, -0.52640571,  0.07171299,\n       -0.29373682,  0.16325583,  0.192765  , -0.01550074,  0.0108685 ,\n       -0.15387057])\n"}︡{"done":true}
︠fa0df57f-eb01-40f7-92f1-97b8f1e5b475s︠
import numpy as np

︡de0b0a3d-70f0-466d-b71d-268b0a718e7a︡{"done":true}
︠cff72c1a-c954-43e9-8416-6a6f90085d23s︠
mpi = np.linalg.pinv(AC4)
9*mpi
︡2f749827-3a92-4b02-961e-f1e910e77fdb︡{"stdout":"array([[ 4.,  1.,  1.,  1.,  1., -2., -2.,  1.,  1., -2.,  1., -2.,  1.,\n         1., -2., -2.],\n       [ 1.,  4.,  1.,  1.,  1.,  1., -2., -2., -2.,  1., -2.,  1., -2.,\n         1.,  1., -2.],\n       [ 1.,  1.,  4.,  1., -2.,  1.,  1., -2.,  1., -2.,  1., -2., -2.,\n        -2.,  1.,  1.],\n       [ 1.,  1.,  1.,  4., -2., -2.,  1.,  1., -2.,  1., -2.,  1.,  1.,\n        -2., -2.,  1.],\n       [ 1.,  1., -2., -2.,  4.,  1.,  1.,  1.,  1., -2., -2.,  1.,  1.,\n        -2.,  1., -2.],\n       [-2.,  1.,  1., -2.,  1.,  4.,  1.,  1.,  1.,  1., -2., -2., -2.,\n         1., -2.,  1.],\n       [-2., -2.,  1.,  1.,  1.,  1.,  4.,  1., -2.,  1.,  1., -2.,  1.,\n        -2.,  1., -2.],\n       [ 1., -2., -2.,  1.,  1.,  1.,  1.,  4., -2., -2.,  1.,  1., -2.,\n         1., -2.,  1.],\n       [ 1., -2.,  1., -2.,  1.,  1., -2., -2.,  4.,  1.,  1.,  1.,  1.,\n        -2., -2.,  1.],\n       [-2.,  1., -2.,  1., -2.,  1.,  1., -2.,  1.,  4.,  1.,  1.,  1.,\n         1., -2., -2.],\n       [ 1., -2.,  1., -2., -2., -2.,  1.,  1.,  1.,  1.,  4.,  1., -2.,\n         1.,  1., -2.],\n       [-2.,  1., -2.,  1.,  1., -2., -2.,  1.,  1.,  1.,  1.,  4., -2.,\n        -2.,  1.,  1.],\n       [ 1., -2., -2.,  1.,  1., -2.,  1., -2.,  1.,  1., -2., -2.,  4.,\n         1.,  1.,  1.],\n       [ 1.,  1., -2., -2., -2.,  1., -2.,  1., -2.,  1.,  1., -2.,  1.,\n         4.,  1.,  1.],\n       [-2.,  1.,  1., -2.,  1., -2.,  1., -2., -2., -2.,  1.,  1.,  1.,\n         1.,  4.,  1.],\n       [-2., -2.,  1.,  1., -2.,  1., -2.,  1.,  1., -2., -2.,  1.,  1.,\n         1.,  1.,  4.]])\n"}︡{"done":true}
︠597aae2b-51e6-4059-bf31-533f250e37f2s︠
AC4
︡19ce8579-ac5f-439a-9081-81409bb2f02e︡{"stdout":"[0 1 1 1 1 0 0 1 1 0 1 0 1 1 0 0]\n[1 0 1 1 1 1 0 0 0 1 0 1 0 1 1 0]\n[1 1 0 1 0 1 1 0 1 0 1 0 0 0 1 1]\n[1 1 1 0 0 0 1 1 0 1 0 1 1 0 0 1]\n[1 1 0 0 0 1 1 1 1 0 0 1 1 0 1 0]\n[0 1 1 0 1 0 1 1 1 1 0 0 0 1 0 1]\n[0 0 1 1 1 1 0 1 0 1 1 0 1 0 1 0]\n[1 0 0 1 1 1 1 0 0 0 1 1 0 1 0 1]\n[1 0 1 0 1 1 0 0 0 1 1 1 1 0 0 1]\n[0 1 0 1 0 1 1 0 1 0 1 1 1 1 0 0]\n[1 0 1 0 0 0 1 1 1 1 0 1 0 1 1 0]\n[0 1 0 1 1 0 0 1 1 1 1 0 0 0 1 1]\n[1 0 0 1 1 0 1 0 1 1 0 0 0 1 1 1]\n[1 1 0 0 0 1 0 1 0 1 1 0 1 0 1 1]\n[0 1 1 0 1 0 1 0 0 0 1 1 1 1 0 1]\n[0 0 1 1 0 1 0 1 1 0 0 1 1 1 1 0]\n"}︡{"done":true}
︠de81df15-9bcf-4f8d-95a5-3436fe649691s︠

X = 81*mpi*AC4*mpi 
X
︡700bd460-5690-4c5c-9ccd-ff5f64595b86︡{"stdout":"array([[0., 1., 1., 1., 1., 0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0.],\n       [1., 0., 1., 1., 1., 1., 0., 0., 0., 1., 0., 1., 0., 1., 1., 0.],\n       [1., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 0., 0., 0., 1., 1.],\n       [1., 1., 1., 0., 0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0., 1.],\n       [1., 1., 0., 0., 0., 1., 1., 1., 1., 0., 0., 1., 1., 0., 1., 0.],\n       [0., 1., 1., 0., 1., 0., 1., 1., 1., 1., 0., 0., 0., 1., 0., 1.],\n       [0., 0., 1., 1., 1., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 0.],\n       [1., 0., 0., 1., 1., 1., 1., 0., 0., 0., 1., 1., 0., 1., 0., 1.],\n       [1., 0., 1., 0., 1., 1., 0., 0., 0., 1., 1., 1., 1., 0., 0., 1.],\n       [0., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 1., 1., 1., 0., 0.],\n       [1., 0., 1., 0., 0., 0., 1., 1., 1., 1., 0., 1., 0., 1., 1., 0.],\n       [0., 1., 0., 1., 1., 0., 0., 1., 1., 1., 1., 0., 0., 0., 1., 1.],\n       [1., 0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0., 0., 1., 1., 1.],\n       [1., 1., 0., 0., 0., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 1.],\n       [0., 1., 1., 0., 1., 0., 1., 0., 0., 0., 1., 1., 1., 1., 0., 1.],\n       [0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0., 1., 1., 1., 1., 0.]])\n"}︡{"done":true}
︠84f7525e-5d0a-452c-89d9-3f067932563fs︠
X
︡1b497584-31c6-4ced-a6f7-8bd14bc41223︡{"stdout":"array([[0., 1., 1., 1., 1., 0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0.],\n       [1., 0., 1., 1., 1., 1., 0., 0., 0., 1., 0., 1., 0., 1., 1., 0.],\n       [1., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 0., 0., 0., 1., 1.],\n       [1., 1., 1., 0., 0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0., 1.],\n       [1., 1., 0., 0., 0., 1., 1., 1., 1., 0., 0., 1., 1., 0., 1., 0.],\n       [0., 1., 1., 0., 1., 0., 1., 1., 1., 1., 0., 0., 0., 1., 0., 1.],\n       [0., 0., 1., 1., 1., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 0.],\n       [1., 0., 0., 1., 1., 1., 1., 0., 0., 0., 1., 1., 0., 1., 0., 1.],\n       [1., 0., 1., 0., 1., 1., 0., 0., 0., 1., 1., 1., 1., 0., 0., 1.],\n       [0., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 1., 1., 1., 0., 0.],\n       [1., 0., 1., 0., 0., 0., 1., 1., 1., 1., 0., 1., 0., 1., 1., 0.],\n       [0., 1., 0., 1., 1., 0., 0., 1., 1., 1., 1., 0., 0., 0., 1., 1.],\n       [1., 0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0., 0., 1., 1., 1.],\n       [1., 1., 0., 0., 0., 1., 0., 1., 0., 1., 1., 0., 1., 0., 1., 1.],\n       [0., 1., 1., 0., 1., 0., 1., 0., 0., 0., 1., 1., 1., 1., 0., 1.],\n       [0., 0., 1., 1., 0., 1., 0., 1., 1., 0., 0., 1., 1., 1., 1., 0.]])\n"}︡{"done":true}
︠65b4d9e3-678e-4ad0-a017-6f7107dad8c0s︠
D = Graph(X, format='adjacency_matrix')
︡27cc1596-c152-4aa2-8277-bad236dadd8a︡{"stderr":"Error in lines 1-1\nTraceback (most recent call last):\n  File \"/cocalc/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 1234, in execute\n    flags=compile_flags), namespace, locals)\n  File \"\", line 1, in <module>\n  File \"/ext/sage/sage-8.9_1804/local/lib/python2.7/site-packages/sage/graphs/graph.py\", line 1147, in __init__\n    from_adjacency_matrix(self, data, loops=loops, multiedges=multiedges, weighted=weighted)\n  File \"/ext/sage/sage-8.9_1804/local/lib/python2.7/site-packages/sage/graphs/graph_input.py\", line 242, in from_adjacency_matrix\n    assert is_Matrix(M)\nAssertionError\n"}︡{"done":true}
︠926ad3f8-cbf1-40c8-8d20-1973882c5c0as︠
k,v = np.linalg.eig(X)
︡b2de8457-5fd7-4fd9-85cc-1c80abffb63b︡{"done":true}
︠35478ffa-f500-4946-adf2-0da12b3b4876s︠
v
︡ac58957d-8593-4fdb-bb9b-cbf9e32cfb7b︡{"stdout":"array([[ 0.25      +0.j        , -0.5528346 +0.j        ,\n        -0.05502842+0.j        ,  0.02658607+0.j        ,\n         0.02833791-0.04265418j,  0.02833791+0.04265418j,\n        -0.10478156+0.j        ,  0.08898718+0.11514002j,\n         0.08898718-0.11514002j, -0.03048058+0.j        ,\n        -0.10393666+0.08032238j, -0.10393666-0.08032238j,\n         0.20169396+0.j        ,  0.65562259+0.j        ,\n        -0.00995683+0.06938734j, -0.00995683-0.06938734j],\n       [ 0.25      +0.j        ,  0.27399859+0.j        ,\n        -0.11954801+0.j        ,  0.30626774+0.j        ,\n        -0.41120219+0.14435661j, -0.41120219-0.14435661j,\n         0.4793877 +0.j        ,  0.01756286+0.08331392j,\n         0.01756286-0.08331392j, -0.0152493 +0.j        ,\n        -0.07180713+0.30566742j, -0.07180713-0.30566742j,\n         0.23544988+0.j        ,  0.18623384+0.j        ,\n        -0.22791527-0.05253595j, -0.22791527+0.05253595j],\n       [ 0.25      +0.j        ,  0.28135196+0.j        ,\n         0.35553444+0.j        , -0.0758409 +0.j        ,\n         0.11704115-0.04393424j,  0.11704115+0.04393424j,\n        -0.29920979+0.j        ,  0.25740895+0.26203276j,\n         0.25740895-0.26203276j,  0.33480118+0.j        ,\n         0.08266917-0.06338336j,  0.08266917+0.06338336j,\n         0.47055999+0.j        ,  0.25751352+0.j        ,\n        -0.19146326+0.16419951j, -0.19146326-0.16419951j],\n       [ 0.25      +0.j        , -0.00251594+0.j        ,\n        -0.18095801+0.j        , -0.25701292+0.j        ,\n         0.26582313-0.05776819j,  0.26582313+0.05776819j,\n        -0.07539634+0.j        , -0.14626332+0.28421727j,\n        -0.14626332-0.28421727j,  0.01002729+0.j        ,\n        -0.0118146 +0.07579985j, -0.0118146 -0.07579985j,\n        -0.16518175+0.j        ,  0.04863275+0.j        ,\n        -0.1149015 +0.01778415j, -0.1149015 -0.01778415j],\n       [ 0.25      +0.j        ,  0.24059138+0.j        ,\n         0.42264589+0.j        , -0.22275277+0.j        ,\n         0.20538549-0.04680866j,  0.20538549+0.04680866j,\n        -0.02056505+0.j        ,  0.03876603-0.13523597j,\n         0.03876603+0.13523597j,  0.09295925+0.j        ,\n        -0.20236834+0.2608729j , -0.20236834-0.2608729j ,\n         0.02997361+0.j        , -0.16718181+0.j        ,\n        -0.01279156+0.21785072j, -0.01279156-0.21785072j],\n       [ 0.25      +0.j        , -0.36724235+0.j        ,\n        -0.23496759+0.j        , -0.21624365+0.j        ,\n         0.19738457+0.05405028j,  0.19738457-0.05405028j,\n        -0.0060579 +0.j        ,  0.13085386-0.08865955j,\n         0.13085386+0.08865955j, -0.21696347+0.j        ,\n         0.15618811+0.15827733j,  0.15618811-0.15827733j,\n        -0.03692162+0.j        , -0.13997726+0.j        ,\n        -0.19668274+0.20623699j, -0.19668274-0.20623699j],\n       [ 0.25      +0.j        , -0.04129833+0.j        ,\n        -0.29596659+0.j        ,  0.55960159+0.j        ,\n        -0.47274391+0.j        , -0.47274391-0.j        ,\n         0.1816379 +0.j        ,  0.00345656-0.06718655j,\n         0.00345656+0.06718655j,  0.36069698+0.j        ,\n        -0.00178186+0.01715739j, -0.00178186-0.01715739j,\n        -0.39537288+0.j        , -0.38503936+0.j        ,\n        -0.00981881+0.0919384j , -0.00981881-0.0919384j ],\n       [ 0.25      +0.j        ,  0.1679493 +0.j        ,\n         0.1082883 +0.j        , -0.12060517+0.j        ,\n         0.06997384-0.00724162j,  0.06997384+0.00724162j,\n        -0.15501496+0.j        , -0.26191204+0.14935521j,\n        -0.26191204-0.14935521j, -0.50669942+0.j        ,\n        -0.26979783-0.0624155j , -0.26979783+0.0624155j ,\n        -0.16362303+0.j        , -0.0054136 +0.j        ,\n        -0.32291397+0.10188381j, -0.32291397-0.10188381j],\n       [ 0.25      +0.j        ,  0.12413503+0.j        ,\n        -0.3686363 +0.j        ,  0.1819835 +0.j        ,\n        -0.13694694-0.06500981j, -0.13694694+0.06500981j,\n        -0.0487734 +0.j        ,  0.0593419 -0.20618867j,\n         0.0593419 +0.20618867j,  0.02229283+0.j        ,\n         0.38095652-0.12533526j,  0.38095652+0.12533526j,\n         0.23064232+0.j        ,  0.1455483 +0.j        ,\n         0.29520019+0.05353887j,  0.29520019-0.05353887j],\n       [ 0.25      +0.j        , -0.14429392+0.j        ,\n         0.47590577+0.j        , -0.31677187+0.j        ,\n         0.30369725-0.09670446j,  0.30369725+0.09670446j,\n        -0.28036156+0.j        , -0.21581366-0.31685807j,\n        -0.21581366+0.31685807j, -0.06001991+0.j        ,\n         0.4270667 +0.j        ,  0.4270667 -0.j        ,\n        -0.42981428+0.j        , -0.14358892+0.j        ,\n         0.26172093-0.28910893j,  0.26172093+0.28910893j],\n       [ 0.25      +0.j        ,  0.14734762+0.j        ,\n         0.06813028+0.j        , -0.13272868+0.j        ,\n        -0.00843213+0.15159823j, -0.00843213-0.15159823j,\n         0.45276475+0.j        , -0.20490728-0.10102783j,\n        -0.20490728+0.10102783j, -0.02498198+0.j        ,\n         0.09556452-0.35987603j,  0.09556452+0.35987603j,\n         0.07922606+0.j        ,  0.1998555 +0.j        ,\n         0.05892793-0.24704675j,  0.05892793+0.24704675j],\n       [ 0.25      +0.j        , -0.12718872+0.j        ,\n        -0.17539975+0.j        ,  0.26751704+0.j        ,\n        -0.15831819+0.01011604j, -0.15831819-0.01011604j,\n        -0.12362979+0.j        , -0.40484833+0.j        ,\n        -0.40484833-0.j        , -0.25221183+0.j        ,\n        -0.0128999 -0.12068305j, -0.0128999 +0.12068305j,\n         0.13769683+0.j        , -0.18927678+0.j        ,\n        -0.04898948-0.17273761j, -0.04898948+0.17273761j],\n       [ 0.25      +0.j        ,  0.18810819+0.j        ,\n         0.00101883+0.j        ,  0.0141832 +0.j        ,\n        -0.09677647+0.15447265j, -0.09677647-0.15447265j,\n         0.17412001+0.j        ,  0.23292099-0.15250725j,\n         0.23292099+0.15250725j,  0.34065241+0.j        ,\n         0.01004153+0.0712066j ,  0.01004153-0.0712066j ,\n        -0.36119406+0.j        , -0.15446761+0.j        ,\n         0.46451839+0.j        ,  0.46451839-0.j        ],\n       [ 0.25      +0.j        ,  0.23753769+0.j        ,\n        -0.12139016+0.j        ,  0.22674778+0.j        ,\n        -0.08987963-0.10170243j, -0.08987963+0.10170243j,\n        -0.19296824+0.j        ,  0.09606911-0.06881942j,\n         0.09606911+0.06881942j, -0.28428285+0.j        ,\n        -0.11738049-0.02221424j, -0.11738049+0.02221424j,\n        -0.15415906+0.j        ,  0.14490169+0.j        ,\n         0.04138221-0.18628702j,  0.04138221+0.18628702j],\n       [ 0.25      +0.j        , -0.38740124+0.j        ,\n        -0.12769813+0.j        , -0.35103201+0.j        ,\n         0.36413489-0.10766398j,  0.36413489+0.10766398j,\n        -0.33519286+0.j        ,  0.17240304+0.0314969j ,\n         0.17240304-0.0314969j ,  0.39092163+0.j        ,\n        -0.28933113-0.0633244j , -0.28933113+0.0633244j ,\n         0.18160221+0.j        , -0.28041193+0.j        ,\n         0.04376696-0.07986111j,  0.04376696+0.07986111j],\n       [ 0.25      +0.j        , -0.03824464+0.j        ,\n         0.24806946+0.j        ,  0.11010104+0.j        ,\n        -0.17747878+0.05489377j, -0.17747878-0.05489377j,\n         0.35404109+0.j        ,  0.13597415+0.21092724j,\n         0.13597415-0.21092724j, -0.16146223+0.j        ,\n        -0.07136862-0.15207203j, -0.07136862+0.15207203j,\n         0.13942183+0.j        , -0.17295092+0.j        ,\n        -0.0300832 +0.10475759j, -0.0300832 -0.10475759j]])"}︡{"stdout":"\n"}︡{"done":true}
︠31000679-8efc-4c89-84d3-e461c55f0bafs︠
X = X.astype(int)
X

︡543173d6-c712-44a6-9f1a-5687ee7d7999︡{"stdout":"array([[0, 0, 1, 1, 1, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0],\n       [0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0],\n       [0, 1, 0, 1, 0, 1, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0],\n       [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0],\n       [0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0],\n       [0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1],\n       [0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0],\n       [0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0],\n       [0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1],\n       [0, 1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0],\n       [0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0],\n       [0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0],\n       [0, 0, 0, 1, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 1],\n       [0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1],\n       [0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 0],\n       [0, 0, 0, 1, 0, 1, 0, 1, 0, 0, 0, 1, 1, 1, 0, 0]])\n"}︡{"done":true}
︠6aa6f778-47af-4ed7-b1fb-f35c24fb4e37s︠
︡eb417095-9a30-4cfa-9bec-9287c20af839︡{"done":true}
︠e81a037d-09be-409a-87fd-b4e67f204057︠









